log

package
v0.0.0-...-832881f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 25, 2025 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

const (
	XmlFormat = "<commit>%n" +
		"<hash>%h</hash>%n" +
		"<names><![CDATA[%d]]></names>%n" +
		"<date>%ci</date>%n" +
		"<author><![CDATA[%an]]></author>%n" +
		"<subject><![CDATA[%s]]></subject>%n" +
		"<body><![CDATA[%n%b%n]]></body>%n" +
		"</commit>"
)

Variables

This section is empty.

Functions

func AbbrevCommit

func AbbrevCommit(g *types.Cmd)

AbbrevCommit is used to display only shortened commit hashes

func AuthoredBy

func AuthoredBy(name string) func(g *types.Cmd)

AuthoredBy let you filter the log by commiter name

func Format

func Format(format string) func(g *types.Cmd)

Format is used to set the --format option

func FromTo

func FromTo(from, to string) func(g *types.Cmd)

FromTo defines the range of the git log

func InTimeFrame

func InTimeFrame(after, before string) func(g *types.Cmd)

InTimeFrame adds --after and --before options

func NameOnly

func NameOnly(g *types.Cmd)

NameOnly is used to output the files changed by the commit

func NameStatus

func NameStatus(g *types.Cmd)

NameStatus shows the changed files and the status (A: added, M: modified...)

func NoCommitID

func NoCommitID(g *types.Cmd)

NoCommitID will only show entries with no commit id

func NoMerges

func NoMerges(g *types.Cmd)

NoMerges is used to exclude merges from the log

func ParseXML

func ParseXML(out string) ([]*types.Commit, error)

ParseXML converts the XML log output to a list of Commit structs

Types

This section is empty.

Jump to