revparse

package
v0.0.0-...-832881f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 25, 2025 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AbbrevRef

func AbbrevRef(g *types.Cmd)

AbbrevRef returns a short rev name for the current state

func ShowTopLevel

func ShowTopLevel(g *types.Cmd)

ShowTopLevel return the absolute path to the git repository's root directory

Types

This section is empty.

Jump to