input

package
v0.0.0-...-832881f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 25, 2025 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

const (
	LocalRef   = 0
	LocalHash  = 1
	RemoteRef  = 2
	RemoteHash = 3
)

Variables

This section is empty.

Functions

func ChangedFiles

func ChangedFiles(appIO io.IO, repo git.Repo) ([]string, error)

ChangedFiles will return a list of changed files It uses a Detector that depending on the executed hook will use different methods to detect the `from` ad `to` references.

func DetectRanges

func DetectRanges(appIO io.IO) []*types.Range

func StagedOrChangedFiles

func StagedOrChangedFiles(appIO io.IO, repo git.Repo) ([]string, error)

StagedOrChangedFiles will return a list of files

  • For `pre-commit` hooks it will return the staged files.
  • For `pre-push` hooks it will return the changed files.

Types

This section is empty.

Jump to