Documentation
¶
Index ¶
- Constants
- func AbbrevCommit(g *types.Cmd)
- func AuthoredBy(name string) func(g *types.Cmd)
- func Format(format string) func(g *types.Cmd)
- func FromTo(from, to string) func(g *types.Cmd)
- func InTimeFrame(after, before string) func(g *types.Cmd)
- func NameOnly(g *types.Cmd)
- func NameStatus(g *types.Cmd)
- func NoCommitID(g *types.Cmd)
- func NoMerges(g *types.Cmd)
- func ParseXML(out string) ([]*types.Commit, error)
Constants ¶
const (
XmlFormat = "<commit>%n" +
"<hash>%h</hash>%n" +
"<names><![CDATA[%d]]></names>%n" +
"<date>%ci</date>%n" +
"<author><![CDATA[%an]]></author>%n" +
"<subject><![CDATA[%s]]></subject>%n" +
"<body><![CDATA[%n%b%n]]></body>%n" +
"</commit>"
)
Variables ¶
This section is empty.
Functions ¶
func AbbrevCommit ¶
AbbrevCommit is used to display only shortened commit hashes
func AuthoredBy ¶
AuthoredBy let you filter the log by commiter name
func InTimeFrame ¶
InTimeFrame adds --after and --before options
func NameStatus ¶
NameStatus shows the changed files and the status (A: added, M: modified...)
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.