Documentation
¶
Index ¶
Constants ¶
const ( LocalRef = 0 LocalHash = 1 RemoteRef = 2 RemoteHash = 3 )
Variables ¶
This section is empty.
Functions ¶
func ChangedFiles ¶
ChangedFiles will return a list of changed files It uses a Detector that depending on the executed hook will use different methods to detect the `from` ad `to` references.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.